@@ -6,7 +6,7 @@ from twisted.python import log
 from twisted.protocols import basic
 from twisted.internet import reactor
 from twisted.internet.defer import inlineCallbacks, returnValue
-from ..errors import (TransferError, WormholeClosedError, UnsendableFileError)
+from ..errors import TransferError, UnsendableFileError
 from wormhole import create, __version__
 from ..transit import TransitSender
 from ..util import dict_to_bytes, bytes_to_dict, bytes_to_hexstr
@@ -92,16 +92,13 @@ class Sender:
         offer, self._fd_to_send = self._build_offer()
         args = self._args
 
-        other_cmd = "wormhole receive"
+        other_cmd = u"wormhole receive"
         if args.verify:
-            other_cmd = "wormhole receive --verify"
+            other_cmd = u"wormhole receive --verify"
         if args.zeromode:
             assert not args.code
             args.code = u"0-"
-            other_cmd += " -0"
-
-        print(u"On the other computer, please run: %s" % other_cmd,
-              file=args.stderr)
+            other_cmd += u" -0"
 
         if args.code:
             w.set_code(args.code)
@@ -111,9 +108,13 @@ class Sender:
         code = yield w.get_code()
         if not args.zeromode:
             print(u"Wormhole code is: %s" % code, file=args.stderr)
-            # flush stderr so the code is displayed immediately
-            args.stderr.flush()
+            other_cmd += u" " + code
+        print(u"On the other computer, please run:", file=args.stderr)
         print(u"", file=args.stderr)
+        print(other_cmd, file=args.stderr)
+        print(u"", file=args.stderr)
+        # flush stderr so the code is displayed immediately
+        args.stderr.flush()
 
         # We don't print a "waiting" message for get_unverified_key() here,
         # even though we do that in cmd_receive.py, because it's not at all
@@ -168,15 +169,9 @@ class Sender:
         self._send_data({"offer": offer}, w)
 
         want_answer = True
-        done = False
 
         while True:
-            try:
-                them_d_bytes = yield w.get_message()
-            except WormholeClosedError:
-                if done:
-                    returnValue(None)
-                raise TransferError("unexpected close")
+            them_d_bytes = yield w.get_message()
             # TODO: get_message() fired, so get_verifier must have fired, so
             # now it's safe to use w.derive_key()
             them_d = bytes_to_dict(them_d_bytes)
@@ -192,8 +187,8 @@ class Sender:
                 recognized = True
                 if not want_answer:
                     raise TransferError("duplicate answer")
+                want_answer = True
                 yield self._handle_answer(them_d[u"answer"])
-                done = True
                 returnValue(None)
             if not recognized:
                 log.msg("unrecognized message %r" % (them_d,))
@@ -243,11 +238,43 @@ class Sender:
         # be unicode or bytes. We need it to be something that can be
         # os.path.joined with the unicode args.what .
         what = os.path.join(args.cwd, args.what)
-        what = what.rstrip(os.sep)
+
+        # We always tell the receiver to create a file (or directory) with the
+        # same basename as what the local user typed, even if the local object
+        # is a symlink to something with a different name. The normpath() is
+        # there to remove trailing slashes.
+        basename = os.path.basename(os.path.normpath(what))
+        assert basename != "", what # normpath shouldn't allow this
+
+        # We use realpath() instead of normpath() to locate the actual
+        # file/directory, because the path might contain symlinks, and
+        # normpath() would collapse those before resolving them.
+        # test_cli.OfferData.test_symlink_collapse tests this.
+
+        # Unfortunately on windows, realpath() (on py3) is built out of
+        # normpath() because of a py2-era belief that windows lacks a working
+        # os.path.islink(): see https://bugs.python.org/issue9949 . The
+        # consequence is that "wormhole send PATH" might send the wrong file,
+        # if:
+        # * we're running on windows
+        # * PATH goes down through a symlink and then up with parent-directory
+        #   navigation (".."), then back down again
+        # * the back-down-again portion of the path also exists under the
+        #   original directory (an error is thrown if not)
+
+        # I'd like to fix this. The core issue is sending directories with a
+        # trailing slash: we need to 1: open the right directory, and 2: strip
+        # the right parent path out of the filenames we get from os.walk(). We
+        # used to use what.rstrip() for this, but bug #251 reported this
+        # failing on windows-with-bash. realpath() works in both those cases,
+        # but fails with the up-down symlinks situation. I think we'll need to
+        # find a third way to strip the trailing slash reliably in all
+        # environments.
+
+        what = os.path.realpath(what)
         if not os.path.exists(what):
             raise TransferError("Cannot send: no file/directory named '%s'" %
                                 args.what)
-        basename = os.path.basename(what)
 
         if os.path.isfile(what):
             # we're sending a file
