@@ -183,6 +183,66 @@ class OfferData(unittest.TestCase):
         self.assertEqual(str(e),
                          "'%s' is neither file nor directory" % filename)
 
+    def test_symlink(self):
+        if not hasattr(os, 'symlink'):
+            raise unittest.SkipTest("host OS does not support symlinks")
+        # build A/B1 -> B2 (==A/B2), and A/B2/C.txt
+        parent_dir = self.mktemp()
+        os.mkdir(parent_dir)
+        os.mkdir(os.path.join(parent_dir, "B2"))
+        with open(os.path.join(parent_dir, "B2", "C.txt"), "wb") as f:
+            f.write(b"success")
+        os.symlink("B2", os.path.join(parent_dir, "B1"))
+        # now send "B1/C.txt" from A, and it should get the right file
+        self.cfg.cwd = parent_dir
+        self.cfg.what = os.path.join("B1", "C.txt")
+        d, fd_to_send = build_offer(self.cfg)
+        self.assertEqual(d["file"]["filename"], "C.txt")
+        self.assertEqual(fd_to_send.read(), b"success")
+
+    def test_symlink_collapse(self):
+        if not hasattr(os, 'symlink'):
+            raise unittest.SkipTest("host OS does not support symlinks")
+        # build A/B1, A/B1/D.txt
+        # A/B2/C2, A/B2/D.txt
+        # symlink A/B1/C1 -> A/B2/C2
+        parent_dir = self.mktemp()
+        os.mkdir(parent_dir)
+        os.mkdir(os.path.join(parent_dir, "B1"))
+        with open(os.path.join(parent_dir, "B1", "D.txt"), "wb") as f:
+            f.write(b"fail")
+        os.mkdir(os.path.join(parent_dir, "B2"))
+        os.mkdir(os.path.join(parent_dir, "B2", "C2"))
+        with open(os.path.join(parent_dir, "B2", "D.txt"), "wb") as f:
+            f.write(b"success")
+        os.symlink(os.path.abspath(os.path.join(parent_dir, "B2", "C2")),
+                   os.path.join(parent_dir, "B1", "C1"))
+        # Now send "B1/C1/../D.txt" from A. The correct traversal will be:
+        # * start: A
+        # * B1: A/B1
+        # * C1: follow symlink to A/B2/C2
+        # * ..: climb to A/B2
+        # * D.txt: open A/B2/D.txt, which contains "success"
+        # If the code mistakenly uses normpath(), it would do:
+        # * normpath turns B1/C1/../D.txt into B1/D.txt
+        # * start: A
+        # * B1: A/B1
+        # * D.txt: open A/B1/D.txt , which contains "fail"
+        self.cfg.cwd = parent_dir
+        self.cfg.what = os.path.join("B1", "C1", os.pardir, "D.txt")
+        d, fd_to_send = build_offer(self.cfg)
+        self.assertEqual(d["file"]["filename"], "D.txt")
+        self.assertEqual(fd_to_send.read(), b"success")
+    if os.name == "nt":
+        test_symlink_collapse.todo = "host OS has broken os.path.realpath()"
+        # ntpath.py's realpath() is built out of normpath(), and does not
+        # follow symlinks properly, so this test always fails. "wormhole send
+        # PATH" on windows will do the wrong thing. See
+        # https://bugs.python.org/issue9949" for details. I'm making this a
+        # TODO instead of a SKIP because 1: this causes an observable
+        # misbehavior (albeit in rare circumstances), 2: it probably used to
+        # work (sometimes, but not in #251). See cmd_send.py for more notes.
+
 class LocaleFinder:
     def __init__(self):
         self._run_once = False
@@ -470,7 +530,7 @@ class PregeneratedCode(ServerBase, ScriptsBase, unittest.TestCase):
                                 ) as mrx_tm:
                     receive_d = cmd_receive.receive(recv_cfg)
             else:
-                KEY_TIMER = 0 if mode == "slow-sender-text" else 1.0
+                KEY_TIMER = 0 if mode == "slow-sender-text" else 99999
                 rxw = []
                 with mock.patch.object(cmd_receive, "KEY_TIMER", KEY_TIMER):
                     send_d = cmd_send.send(send_cfg)
@@ -484,7 +544,7 @@ class PregeneratedCode(ServerBase, ScriptsBase, unittest.TestCase):
 
             # The sender might fail, leaving the receiver hanging, or vice
             # versa. Make sure we don't wait on one side exclusively
-            VERIFY_TIMER = 0 if mode == "slow-text" else 1.0
+            VERIFY_TIMER = 0 if mode == "slow-text" else 99999
             with mock.patch.object(cmd_receive, "VERIFY_TIMER", VERIFY_TIMER):
                 with mock.patch.object(cmd_send, "VERIFY_TIMER", VERIFY_TIMER):
                     if mock_accept:
@@ -529,9 +589,9 @@ class PregeneratedCode(ServerBase, ScriptsBase, unittest.TestCase):
         # check sender
         if mode == "text" or mode == "slow-text":
             expected = ("Sending text message ({bytes:d} Bytes){NL}"
-                        "On the other computer, please run: "
-                        "wormhole receive{NL}"
-                        "Wormhole code is: {code}{NL}{NL}"
+                        "Wormhole code is: {code}{NL}"
+                        "On the other computer, please run:{NL}{NL}"
+                        "wormhole receive {code}{NL}{NL}"
                         "{KE}"
                         "text message sent{NL}").format(bytes=len(message),
                                                         code=send_cfg.code,
@@ -543,9 +603,9 @@ class PregeneratedCode(ServerBase, ScriptsBase, unittest.TestCase):
                               .format(size=naturalsize(len(message)),
                                       name=send_filename,
                                       NL=NL), send_stderr)
-            self.failUnlessIn(u"On the other computer, please run: "
-                              "wormhole receive{NL}"
-                              "Wormhole code is: {code}{NL}{NL}"
+            self.failUnlessIn(u"Wormhole code is: {code}{NL}"
+                              "On the other computer, please run:{NL}{NL}"
+                              "wormhole receive {code}{NL}{NL}"
                               .format(code=send_cfg.code, NL=NL),
                               send_stderr)
             self.failUnlessIn(u"File sent.. waiting for confirmation{NL}"
@@ -554,9 +614,9 @@ class PregeneratedCode(ServerBase, ScriptsBase, unittest.TestCase):
         elif mode == "directory":
             self.failUnlessIn(u"Sending directory", send_stderr)
             self.failUnlessIn(u"named 'testdir'", send_stderr)
-            self.failUnlessIn(u"On the other computer, please run: "
-                              "wormhole receive{NL}"
-                              "Wormhole code is: {code}{NL}{NL}"
+            self.failUnlessIn(u"Wormhole code is: {code}{NL}"
+                              "On the other computer, please run:{NL}{NL}"
+                              "wormhole receive {code}{NL}{NL}"
                               .format(code=send_cfg.code, NL=NL), send_stderr)
             self.failUnlessIn(u"File sent.. waiting for confirmation{NL}"
                               "Confirmation received. Transfer complete.{NL}"
@@ -728,9 +788,9 @@ class PregeneratedCode(ServerBase, ScriptsBase, unittest.TestCase):
                               .format(size=naturalsize(size),
                                       name=send_filename,
                                       NL=NL), send_stderr)
-            self.failUnlessIn("On the other computer, please run: "
-                              "wormhole receive{NL}"
-                              "Wormhole code is: {code}{NL}{NL}"
+            self.failUnlessIn("Wormhole code is: {code}{NL}"
+                              "On the other computer, please run:{NL}{NL}"
+                              "wormhole receive {code}{NL}"
                               .format(code=send_cfg.code, NL=NL),
                               send_stderr)
             self.failIfIn("File sent.. waiting for confirmation{NL}"
@@ -739,9 +799,9 @@ class PregeneratedCode(ServerBase, ScriptsBase, unittest.TestCase):
         elif mode == "directory":
             self.failUnlessIn("Sending directory", send_stderr)
             self.failUnlessIn("named 'testdir'", send_stderr)
-            self.failUnlessIn("On the other computer, please run: "
-                              "wormhole receive{NL}"
-                              "Wormhole code is: {code}{NL}{NL}"
+            self.failUnlessIn("Wormhole code is: {code}{NL}"
+                              "On the other computer, please run:{NL}{NL}"
+                              "wormhole receive {code}{NL}"
                               .format(code=send_cfg.code, NL=NL), send_stderr)
             self.failIfIn("File sent.. waiting for confirmation{NL}"
                           "Confirmation received. Transfer complete.{NL}"
@@ -833,8 +893,10 @@ class ZeroMode(ServerBase, unittest.TestCase):
 
         # check sender
         expected = ("Sending text message ({bytes:d} Bytes){NL}"
-                    "On the other computer, please run: "
-                    "wormhole receive -0{NL}{NL}"
+                    "On the other computer, please run:{NL}"
+                    "{NL}"
+                    "wormhole receive -0{NL}"
+                    "{NL}"
                     "text message sent{NL}").format(bytes=len(message),
                                                     code=send_cfg.code,
                                                     NL=NL)
