@@ -13,13 +13,11 @@ from ..server.database import get_db
 
 def easy_relay(
         rendezvous_web_port=str("tcp:0"),
-        transit_port=str("tcp:0"),
         advertise_version=None,
         **kwargs
 ):
     return server.RelayServer(
         rendezvous_web_port,
-        transit_port,
         advertise_version,
         **kwargs
     )
@@ -33,7 +31,7 @@ class RLimits(unittest.TestCase):
         # is easier than just passing "tcp:0"
         ep = endpoints.TCP4ServerEndpoint(None, 0)
         with patch_s("endpoints.serverFromString", return_value=ep):
-            s = server.RelayServer("fake", None, None)
+            s = server.RelayServer("fake", None)
         fakelog = []
         def checklog(*expected):
             self.assertEqual(fakelog, list(expected))
@@ -621,11 +619,9 @@ class WSClientSync(unittest.TestCase):
             kwargs["type"] = mtype
             c.onMessage(json.dumps(kwargs).encode("utf-8"), False)
         # no queued messages
-        sunc = []
         d = c.sync()
-        d.addBoth(sunc.append)
         self.assertEqual(sent, [("ping", {"ping": 0})])
-        self.assertEqual(sunc, [])
+        self.assertNoResult(d)
         add("pong", pong=0)
         yield d
         self.assertEqual(c.events, [])
@@ -633,9 +629,7 @@ class WSClientSync(unittest.TestCase):
         # one,two,ping,pong
         add("one")
         add("two", two=2)
-        sunc = []
         d = c.sync()
-        d.addBoth(sunc.append)
         add("pong", pong=1)
         yield d
         m = yield c.next_non_ack()
@@ -646,9 +640,7 @@ class WSClientSync(unittest.TestCase):
 
         # one,ping,two,pong
         add("one")
-        sunc = []
         d = c.sync()
-        d.addBoth(sunc.append)
         add("two", two=2)
         add("pong", pong=2)
         yield d
@@ -659,9 +651,7 @@ class WSClientSync(unittest.TestCase):
         self.assertEqual(c.events, [])
 
         # ping,one,two,pong
-        sunc = []
         d = c.sync()
-        d.addBoth(sunc.append)
         add("one")
         add("two", two=2)
         add("pong", pong=3)
@@ -1403,7 +1393,6 @@ class DumpStats(unittest.TestCase):
         self.assertEqual(data["created"], now)
         self.assertEqual(data["valid_until"], now+validity)
         self.assertEqual(data["rendezvous"]["all_time"]["mailboxes_total"], 0)
-        self.assertEqual(data["transit"]["all_time"]["total"], 0)
 
 
 class Startup(unittest.TestCase):
